==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ko/persian.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "지난 화요일",
	"field-year": "년",
	"field-wed-relative+0": "이번 수요일",
	"field-wed-relative+1": "다음 수요일",
	"timeFormat-short": "a h:mm",
	"field-minute": "분",
	"field-tue-narrow-relative+0": "이번 화요일",
	"field-tue-narrow-relative+1": "다음 화요일",
	"field-thu-short-relative+0": "이번 목요일",
	"field-thu-short-relative+1": "다음 목요일",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-day-relative+2": "모레",
	"field-wed-narrow-relative+-1": "지난 수요일",
	"field-year-narrow": "년",
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"field-second-short": "초",
	"dateFormatItem-MMMd": "MMM월 d일",
	"field-week-relative+0": "이번 주",
	"field-month-relative+0": "이번 달",
	"field-week-relative+1": "다음 주",
	"field-month-relative+1": "다음 달",
	"field-sun-narrow-relative+0": "이번 일요일",
	"timeFormat-medium": "a h:mm:ss",
	"field-mon-short-relative+0": "이번 월요일",
	"field-sun-narrow-relative+1": "다음 일요일",
	"field-mon-short-relative+1": "다음 월요일",
	"field-second-relative+0": "지금",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"months-standAlone-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"field-month-short": "월",
	"dateFormatItem-GyMMMEd": "G y년 MMM월 d일 (E)",
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"field-day": "일",
	"field-year-relative+-1": "작년",
	"dayPeriods-format-wide-am": "오전",
	"field-sat-short-relative+-1": "지난 토요일",
	"field-hour-relative+0": "현재 시간",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"field-wed-relative+-1": "지난 수요일",
	"field-sat-narrow-relative+-1": "지난 토요일",
	"field-second": "초",
	"days-standAlone-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-standAlone-wide-pm": "오후",
	"dateFormat-long": "G y년 M월 d일",
	"dateFormatItem-GyMMMd": "G y년 MMM월 d일",
	"field-quarter": "분기",
	"field-week-short": "주",
	"quarters-standAlone-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"days-format-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-tue-short-relative+0": "이번 화요일",
	"field-tue-short-relative+1": "다음 화요일",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-GyMMM": "G y년 MMM월",
	"field-month": "월",
	"field-day-narrow": "일",
	"field-minute-short": "분",
	"field-dayperiod": "오전/오후",
	"field-sat-short-relative+0": "이번 토요일",
	"field-sat-short-relative+1": "다음 토요일",
	"dateFormat-medium": "G y. M. d.",
	"dateFormatItem-yyyyMMMM": "G y년 MMMM월",
	"quarters-standAlone-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"dateFormatItem-yyyyM": "G y. M.",
	"field-second-narrow": "초",
	"field-mon-relative+0": "이번 월요일",
	"field-mon-relative+1": "다음 월요일",
	"field-year-short": "년",
	"months-format-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"field-quarter-relative+-1": "지난 분기",
	"dateFormatItem-yyyyMMMd": "G y년 MMM월 d일",
	"days-format-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-format-wide-pm": "오후",
	"field-sat-relative+-1": "지난 토요일",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "시",
	"months-format-wide": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-Hms": "H시 m분 s초",
	"field-quarter-short": "분기",
	"field-sat-narrow-relative+0": "이번 토요일",
	"field-fri-relative+0": "이번 금요일",
	"field-sat-narrow-relative+1": "다음 토요일",
	"field-fri-relative+1": "다음 금요일",
	"field-sun-short-relative+0": "이번 일요일",
	"field-sun-short-relative+1": "다음 일요일",
	"field-week-relative+-1": "지난주",
	"months-format-abbr": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"field-quarter-relative+0": "이번 분기",
	"field-minute-relative+0": "현재 분",
	"timeFormat-long": "a h시 m분 s초 z",
	"field-quarter-relative+1": "다음 분기",
	"field-wed-short-relative+-1": "지난 수요일",
	"dateFormat-short": "G y. M. d.",
	"field-thu-short-relative+-1": "지난 목요일",
	"days-standAlone-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"dateFormatItem-yyyyMMMEd": "G y년 MMM월 d일 (E)",
	"field-mon-narrow-relative+-1": "지난 월요일",
	"dateFormatItem-MMMMd": "MMMM월 d일",
	"field-thu-narrow-relative+-1": "지난 목요일",
	"field-tue-narrow-relative+-1": "지난 화요일",
	"dateFormatItem-H": "H시",
	"dateFormatItem-yyyy": "G y년",
	"field-wed-short-relative+0": "이번 수요일",
	"dateFormatItem-M": "M월",
	"months-standAlone-wide": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"field-wed-short-relative+1": "다음 수요일",
	"field-sun-relative+-1": "지난 일요일",
	"days-standAlone-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-d": "d일",
	"field-weekday": "요일",
	"field-sat-relative+0": "이번 토요일",
	"dateFormatItem-h": "a h시",
	"field-sat-relative+1": "다음 토요일",
	"months-standAlone-abbr": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"timeFormat-full": "a h시 m분 s초 zzzz",
	"dateFormatItem-MEd": "M. d. (E)",
	"dateFormatItem-y": "G y년",
	"field-thu-narrow-relative+0": "이번 목요일",
	"field-thu-narrow-relative+1": "다음 목요일",
	"field-sun-narrow-relative+-1": "지난 일요일",
	"field-mon-short-relative+-1": "지난 월요일",
	"field-thu-relative+0": "이번 목요일",
	"field-thu-relative+1": "다음 목요일",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-fri-short-relative+-1": "지난 금요일",
	"field-thu-relative+-1": "지난 목요일",
	"field-week": "주",
	"quarters-format-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"dateFormatItem-Ed": "d일 (E)",
	"field-wed-narrow-relative+0": "이번 수요일",
	"field-wed-narrow-relative+1": "다음 수요일",
	"dateFormatItem-yyyyMMM": "G y년 MMM월",
	"field-fri-short-relative+0": "이번 금요일",
	"field-fri-short-relative+1": "다음 금요일",
	"days-standAlone-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"field-hour-short": "시",
	"quarters-format-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"field-month-narrow": "월",
	"field-hour-narrow": "시",
	"field-fri-narrow-relative+-1": "지난 금요일",
	"field-year-relative+0": "올해",
	"field-year-relative+1": "내년",
	"field-fri-relative+-1": "지난 금요일",
	"field-tue-short-relative+-1": "지난 화요일",
	"field-minute-narrow": "분",
	"days-format-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"field-mon-narrow-relative+0": "이번 월요일",
	"field-mon-narrow-relative+1": "다음 월요일",
	"field-zone": "시간대",
	"dateFormatItem-MMMEd": "MMM월 d일 (E)",
	"field-quarter-narrow": "분기",
	"field-sun-short-relative+-1": "지난 일요일",
	"field-day-relative+-1": "어제",
	"field-day-relative+-2": "그저께",
	"days-format-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-sun-relative+0": "이번 일요일",
	"field-sun-relative+1": "다음 일요일",
	"dateFormatItem-Gy": "G y년",
	"field-day-short": "일",
	"field-week-narrow": "주",
	"field-era": "연호",
	"field-fri-narrow-relative+0": "이번 금요일",
	"field-fri-narrow-relative+1": "다음 금요일",
	"dayPeriods-standAlone-wide-am": "오전"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/ko/persian.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "지난 화요일",
	"field-year": "년",
	"field-wed-relative+0": "이번 수요일",
	"field-wed-relative+1": "다음 수요일",
	"timeFormat-short": "a h:mm",
	"field-minute": "분",
	"field-tue-narrow-relative+0": "이번 화요일",
	"field-tue-narrow-relative+1": "다음 화요일",
	"field-thu-short-relative+0": "이번 목요일",
	"field-thu-short-relative+1": "다음 목요일",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-day-relative+2": "모레",
	"field-wed-narrow-relative+-1": "지난 수요일",
	"dateFormatItem-EBhms": "E B h:mm:ss",
	"field-year-narrow": "년",
	"field-era-short": "연호",
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"field-weekdayOfMonth": "월의 평일",
	"field-second-short": "초",
	"dateFormatItem-MMMd": "M월 d일",
	"field-weekdayOfMonth-narrow": "월의 평일",
	"field-week-relative+0": "이번 주",
	"field-month-relative+0": "이번 달",
	"field-week-relative+1": "다음 주",
	"field-month-relative+1": "다음 달",
	"field-sun-narrow-relative+0": "이번 일요일",
	"timeFormat-medium": "a h:mm:ss",
	"field-mon-short-relative+0": "이번 월요일",
	"field-sun-narrow-relative+1": "다음 일요일",
	"field-mon-short-relative+1": "다음 월요일",
	"field-second-relative+0": "지금",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"months-standAlone-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"field-weekOfMonth": "월의 주",
	"field-month-short": "월",
	"dateFormatItem-GyMMMEd": "G y년 M월 d일 (E)",
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"field-day": "일",
	"field-dayOfYear-short": "년의 일",
	"field-year-relative+-1": "작년",
	"dayPeriods-format-wide-am": "오전",
	"field-sat-short-relative+-1": "지난 토요일",
	"field-hour-relative+0": "현재 시간",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"field-wed-relative+-1": "지난 수요일",
	"field-sat-narrow-relative+-1": "지난 토요일",
	"field-second": "초",
	"days-standAlone-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-standAlone-wide-pm": "오후",
	"dateFormatItem-Ehms": "E a h:mm:ss",
	"dateFormat-long": "G y년 M월 d일",
	"dateFormatItem-GyMMMd": "G y년 M월 d일",
	"field-quarter": "분기",
	"field-week-short": "주",
	"quarters-standAlone-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"days-format-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-tue-short-relative+0": "이번 화요일",
	"field-tue-short-relative+1": "다음 화요일",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-GyMMM": "G y년 M월",
	"field-month": "월",
	"field-day-narrow": "일",
	"field-minute-short": "분",
	"field-dayperiod": "오전/오후",
	"field-sat-short-relative+0": "이번 토요일",
	"field-sat-short-relative+1": "다음 토요일",
	"dateFormat-medium": "G y. M. d.",
	"dateFormatItem-yyyyMMMM": "G y년 M월",
	"quarters-standAlone-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"dateFormatItem-yyyyM": "G y. M.",
	"field-second-narrow": "초",
	"field-mon-relative+0": "이번 월요일",
	"field-mon-relative+1": "다음 월요일",
	"field-year-short": "년",
	"months-format-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"field-quarter-relative+-1": "지난 분기",
	"dateFormatItem-yyyyMMMd": "G y년 M월 d일",
	"field-dayperiod-narrow": "오전/오후",
	"days-format-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-format-wide-pm": "오후",
	"field-dayOfYear": "년의 일",
	"field-sat-relative+-1": "지난 토요일",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "시",
	"months-format-wide": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"field-month-relative+-1": "지난달",
	"field-quarter-short": "분기",
	"field-sat-narrow-relative+0": "이번 토요일",
	"field-fri-relative+0": "이번 금요일",
	"field-sat-narrow-relative+1": "다음 토요일",
	"field-fri-relative+1": "다음 금요일",
	"dateFormatItem-EBhm": "E B h:mm",
	"field-sun-short-relative+0": "이번 일요일",
	"field-sun-short-relative+1": "다음 일요일",
	"field-week-relative+-1": "지난주",
	"dateFormatItem-Ehm": "E a h:mm",
	"months-format-abbr": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"field-quarter-relative+0": "이번 분기",
	"field-minute-relative+0": "현재 분",
	"timeFormat-long": "a h시 m분 s초 z",
	"field-quarter-relative+1": "다음 분기",
	"field-wed-short-relative+-1": "지난 수요일",
	"dateFormat-short": "G y. M. d.",
	"dateFormatItem-Bh": "B h시",
	"field-thu-short-relative+-1": "지난 목요일",
	"days-standAlone-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"dateFormatItem-yyyyMMMEd": "G y년 M월 d일 (E)",
	"field-mon-narrow-relative+-1": "지난 월요일",
	"dateFormatItem-MMMMd": "M월 d일",
	"field-thu-narrow-relative+-1": "지난 목요일",
	"field-tue-narrow-relative+-1": "지난 화요일",
	"dateFormatItem-H": "H시",
	"field-weekOfMonth-short": "월의 주",
	"dateFormatItem-yyyy": "G y년",
	"field-wed-short-relative+0": "이번 수요일",
	"dateFormatItem-M": "M월",
	"months-standAlone-wide": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"field-wed-short-relative+1": "다음 수요일",
	"field-sun-relative+-1": "지난 일요일",
	"days-standAlone-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-d": "d일",
	"field-weekday": "요일",
	"field-sat-relative+0": "이번 토요일",
	"dateFormatItem-h": "a h시",
	"field-sat-relative+1": "다음 토요일",
	"months-standAlone-abbr": [
		"화르바딘",
		"오르디베헤쉬트",
		"호르다드",
		"티르",
		"모르다드",
		"샤흐리바르",
		"메흐르",
		"아반",
		"아자르",
		"다이",
		"바흐만",
		"에스판드"
	],
	"field-dayOfYear-narrow": "년의 일",
	"field-weekdayOfMonth-short": "월의 평일",
	"timeFormat-full": "a h시 m분 s초 zzzz",
	"dateFormatItem-MEd": "M. d. (E)",
	"field-zone-narrow": "시간대",
	"dateFormatItem-y": "G y년",
	"field-thu-narrow-relative+0": "이번 목요일",
	"field-thu-narrow-relative+1": "다음 목요일",
	"field-sun-narrow-relative+-1": "지난 일요일",
	"field-mon-short-relative+-1": "지난 월요일",
	"field-thu-relative+0": "이번 목요일",
	"field-thu-relative+1": "다음 목요일",
	"field-fri-short-relative+-1": "지난 금요일",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-thu-relative+-1": "지난 목요일",
	"field-week": "주",
	"quarters-format-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"dateFormatItem-Ed": "d일 (E)",
	"field-wed-narrow-relative+0": "이번 수요일",
	"field-wed-narrow-relative+1": "다음 수요일",
	"field-dayperiod-short": "오전/오후",
	"dateFormatItem-yyyyMMM": "G y년 M월",
	"field-fri-short-relative+0": "이번 금요일",
	"field-fri-short-relative+1": "다음 금요일",
	"days-standAlone-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"field-zone-short": "시간대",
	"field-hour-short": "시",
	"quarters-format-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"field-month-narrow": "월",
	"field-hour-narrow": "시",
	"field-fri-narrow-relative+-1": "지난 금요일",
	"field-year-relative+0": "올해",
	"field-year-relative+1": "내년",
	"field-era-narrow": "연호",
	"field-fri-relative+-1": "지난 금요일",
	"dateFormatItem-Bhms": "B h:mm:ss",
	"field-tue-short-relative+-1": "지난 화요일",
	"field-minute-narrow": "분",
	"days-format-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"field-mon-narrow-relative+0": "이번 월요일",
	"field-mon-narrow-relative+1": "다음 월요일",
	"field-zone": "시간대",
	"dateFormatItem-MMMEd": "M월 d일 (E)",
	"field-weekOfMonth-narrow": "월의 주",
	"field-weekday-narrow": "요일",
	"field-quarter-narrow": "분기",
	"field-sun-short-relative+-1": "지난 일요일",
	"field-day-relative+-1": "어제",
	"field-day-relative+-2": "그저께",
	"field-weekday-short": "요일",
	"days-format-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateFormatItem-Bhm": "B h:mm",
	"field-sun-relative+0": "이번 일요일",
	"field-sun-relative+1": "다음 일요일",
	"dateFormatItem-Gy": "G y년",
	"field-day-short": "일",
	"field-week-narrow": "주",
	"field-era": "연호",
	"field-fri-narrow-relative+0": "이번 금요일",
	"field-fri-narrow-relative+1": "다음 금요일",
	"dayPeriods-standAlone-wide-am": "오전"
}
//end v1.x content
);
